pipenv-unlock is_lock
======================

Check whether ``pyproject.toml`` required and optional dependencies are
in a lock or unlock state

Normal usage
-------------

.. code-block:: shell

   pipenv-unlock is_lock

unlock state
-------------

author:

- is overworked

- has a life

- discovered girls

- has several vices which may or may not overlap

- will never approve a merge-request generated by CI/CD

This is what drain-swamp assumes

- Might get a job one day. Dusts off and dons cape

lock state
------------

author:

- has no life

- is immortal

- wears a cape

- constantly paying attention

- quickly responds to issues and PRs

- As soon as CI/CD makes a merge request, within seconds: updates
  dependency versions and rolls out a new release

This is what pip-tools assumes

Exit codes
-----------

0 -- is locked
1 -- is unlocked
2 -- Path not a file
3 -- file is not ok for whatever reason
4 -- Static dependencies. No tool.setuptools.dynamic section

Command options
-----------------

.. csv-table:: :code:`pipenv-unlock is_lock` options
   :header: cli, default, description
   :widths: auto

   "-p/--path", "cwd", "absolute path to package base folder"
